==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_RichTextAttr.h <==
//----------------------------------------------------------------------------
// wxRichTextAttr
// extracted from richtextattr.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_RICHTEXTATTR_H__
#define __CLASS_WX_RICHTEXTATTR_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxRichTextAttr
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_RichTextAttr);

//----------------------------------------------------------------------------
// Object declaration for wxRichTextAttr
//----------------------------------------------------------------------------
class Object_wx_RichTextAttr : public Object {
protected:
	wxRichTextAttr *_pEntity;
	GuraObjectObserver *_pObserver;
	bool _ownerFlag;
public:
	Gura_DeclareObjectAccessor(wx_RichTextAttr)
public:
	inline Object_wx_RichTextAttr(wxRichTextAttr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(Gura_UserClass(wx_RichTextAttr)),
				_pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	inline Object_wx_RichTextAttr(Class *pClass, wxRichTextAttr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(pClass), _pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	virtual ~Object_wx_RichTextAttr();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline void SetEntity(wxRichTextAttr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) {
		if (_ownerFlag) delete _pEntity;
		_pEntity = pEntity;
		_pObserver = pObserver;
		_ownerFlag = ownerFlag;
	}
	inline void InvalidateEntity() { _pEntity = NULL, _pObserver = NULL, _ownerFlag = false; }
	inline wxRichTextAttr *GetEntity() { return _pEntity; }
	inline wxRichTextAttr *ReleaseEntity() {
		wxRichTextAttr *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline void NotifyGuraObjectDeleted() {
		if (_pObserver != NULL) _pObserver->GuraObjectDeleted();
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxRichTextAttr");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_RichTextAttr.h <==
//----------------------------------------------------------------------------
// wxRichTextAttr
// extracted from richtextattr.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_RICHTEXTATTR_H__
#define __CLASS_WX_RICHTEXTATTR_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxRichTextAttr
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_RichTextAttr);

//----------------------------------------------------------------------------
// Object declaration for wxRichTextAttr
//----------------------------------------------------------------------------
class Object_wx_RichTextAttr : public Object {
protected:
	wxRichTextAttr *_pEntity;
	GuraObjectObserver *_pObserver;
	bool _ownerFlag;
public:
	Gura_DeclareObjectAccessor(wx_RichTextAttr)
public:
	inline Object_wx_RichTextAttr(wxRichTextAttr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(Gura_UserClass(wx_RichTextAttr)),
				_pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	inline Object_wx_RichTextAttr(Class *pClass, wxRichTextAttr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object(pClass), _pEntity(pEntity), _pObserver(pObserver), _ownerFlag(ownerFlag) {}
	virtual ~Object_wx_RichTextAttr();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline void SetEntity(wxRichTextAttr *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) {
		if (_ownerFlag) delete _pEntity;
		_pEntity = pEntity;
		_pObserver = pObserver;
		_ownerFlag = ownerFlag;
	}
	inline void InvalidateEntity() { _pEntity = nullptr, _pObserver = nullptr, _ownerFlag = false; }
	inline wxRichTextAttr *GetEntity() { return _pEntity; }
	inline wxRichTextAttr *ReleaseEntity() {
		wxRichTextAttr *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline void NotifyGuraObjectDeleted() {
		if (_pObserver != nullptr) _pObserver->GuraObjectDeleted();
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxRichTextAttr");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
